==> nautilus-0.1.0.tar.gz: nautilus-0.1.0/libnautilus-extensions/nautilus-undo-signal-handlers.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* Signal handlers to enable undo in Gtk Widgets.
 *
 * Copyright (C) 2000 Eazel, Inc.
 *
 * Author: Gene Z. Ragan <gzr@eazel.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef NAUTILUS_UNDO_SIGNAL_HANDLERS_H
#define NAUTILUS_UNDO_SIGNAL_HANDLERS_H

#include <libnautilus-extensions/nautilus-entry.h>

void nautilus_undo_setup_nautilus_entry_for_undo 	(NautilusEntry	*entry);
void nautilus_undo_teardown_nautilus_entry_for_undo 	(NautilusEntry	*entry);
void nautilus_undo_setup_editable_for_undo 		(GtkEditable 	*editable);
void nautilus_undo_teardown_editable_for_undo 		(GtkEditable 	*editable);
void nautilus_undo_editable_set_undo_key 		(GtkEditable 	*editable, 
							 gboolean 	value);

#endif /* NAUTILUS_UNDO_SIGNAL_HANDLERS_H */

==> nautilus-0.8.tar.gz: nautilus-0.8/libnautilus-extensions/nautilus-undo-signal-handlers.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* Signal handlers to enable undo in Gtk Widgets.
 *
 * Copyright (C) 2000 Eazel, Inc.
 *
 * Author: Gene Z. Ragan <gzr@eazel.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef NAUTILUS_UNDO_SIGNAL_HANDLERS_H
#define NAUTILUS_UNDO_SIGNAL_HANDLERS_H

#include <libnautilus-extensions/nautilus-entry.h>

void nautilus_undo_set_up_nautilus_entry_for_undo 	(NautilusEntry	*entry);
void nautilus_undo_tear_down_nautilus_entry_for_undo 	(NautilusEntry	*entry);
void nautilus_undo_set_up_editable_for_undo 		(GtkEditable 	*editable);
void nautilus_undo_tear_down_editable_for_undo 		(GtkEditable 	*editable);
void nautilus_undo_editable_set_undo_key 		(GtkEditable 	*editable, 
							 gboolean 	value);

#endif /* NAUTILUS_UNDO_SIGNAL_HANDLERS_H */
